@@ -6,6 +6,7 @@ import os
 import re
 from pathlib import Path
 
+import psutil as psutil
 import yaml
 from colorama import Fore, Style
 from yarl import URL
@@ -69,6 +70,7 @@ async def clear() -> None:
 
 async def make_title_safe(title: str):
     title = re.sub(r'[\\*?:"<>|./]', "-", title)
+    title = title[:60].rstrip()
     return title
 
 
@@ -99,6 +101,15 @@ async def regex_links(urls) -> list:
     return yarl_links
 
 
+async def check_free_space(required_space: int, download_directory: Path):
+    free_space = psutil.disk_usage(str(download_directory.parent)).free
+    free_space = ((free_space / 1024) / 1024) / 1024
+    if required_space > free_space:
+        return False
+    else:
+        return True
+
+
 async def cyberdrop_parse(url: URL) -> URL:
     mapping_direct = [r'img-...cyberdrop...',
                       r'f.cyberdrop...', r'fs-...cyberdrop...']
