@@ -154,6 +154,6 @@ class AuthData:
 class SkipData:
     supported_hosts: ClassVar[Tuple[str]] = (
         "anonfiles", "bunkr", "coomer.party", "cyberdrop", "cyberfile", "erome", "fapello", "gfycat",
-        "gofile", "hgamecg", "imgbox", "img.kiwi", "jpg.church", "kemono.party", "pixeldrain", "pixl.li", "postimg.cc",
-        "redgifs", "rule34", "saint", "socialmediagirls", "simpcity", "xbunker", "xbunkr")
+        "gofile", "hgamecg", "imgbox", "img.kiwi", "jpg.church", "jpg.fish", "pixeldrain", "pixl.li", "postimg.cc",
+        "redgifs", "rule34", "saint", "socialmediagirls", "simpcity", "xbunker", "xbunkr", "kemono")
     sites: List[str]
