@@ -88,20 +88,20 @@ class ScrapeMapper:
 
         self.crawlers = [self.anonfiles_crawler, self.bunkr_crawler, self.cyberdrop_crawler, self.coomer_crawler,
                          self.cyberfile_crawler, self.erome_crawler, self.gfycat_crawler, self.gofile_crawler,
-                         self.hgamecg_crawler, self.imgbox_crawler, self.kemono_crawler, self.pixeldrain_crawler,
+                         self.hgamecg_crawler, self.imgbox_crawler, self.pixeldrain_crawler,
                          self.postimg_crawler, self.redgifs_crawler, self.rule34_crawler, self.saint_crawler,
                          self.sharex_crawler, self.socialmediagirls_crawler, self.simpcity_crawler,
-                         self.xbunker_crawler, self.xbunkr_crawler]
+                         self.xbunker_crawler, self.xbunkr_crawler, self.kemono_crawler]
 
         self.mapping = {"anonfiles.com": self.Anonfiles, "xbunkr": self.XBunkr,
                         "bunkr": self.Bunkr, "coomer.party": self.Coomer, "cyberdrop": self.Cyberdrop,
-                        "cyberfile.is": self.Cyberfile, "cyberfile.su": self.Cyberfile, "erome.com": self.Erome,
+                        "cyberfile": self.Cyberfile, "cyberfile.su": self.Cyberfile, "erome.com": self.Erome,
                         "fapello": self.Fapello, "gfycat.com": self.Gfycat, "gofile.io": self.GoFile,
                         "hgamecg.com": self.HGameCG, "imgbox.com": self.ImgBox, "img.kiwi": self.ShareX,
-                        "jpg.church": self.ShareX, "kemono.party": self.Kemono, "pixeldrain.com": self.Pixeldrain,
+                        "jpg.church": self.ShareX, "jpg.fish": self.ShareX, "pixeldrain.com": self.Pixeldrain,
                         "pixl.li": self.ShareX, "postimg": self.Postimg, "redgifs.com": self.Redgifs,
                         "rule34.xxx": self.Rule34, "saint.to": self.Saint,  "socialmediagirls": self.SocialMediaGirls,
-                        "simpcity": self.SimpCity, "xbunker": self.XBunker}
+                        "simpcity": self.SimpCity, "xbunker": self.XBunker, "kemono": self.Kemono}
 
     async def Anonfiles(self, url: URL, title=None):
         anonfiles_session = Session(self.client)
